@@ -1,6 +1,7 @@
 import numpy
 import datetime
-from stock_core.load_db import Corps, Settings
+from stock_core.load_db import Corps
+
 import logging
 logger = logging.getLogger(__name__)
 formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
