@@ -756,17 +756,17 @@ class ReportOne:
         return {
             'code': self.eval_dict['c101']['코드'],
             '종목명': self.eval_dict['c101']['종목명'],
-            '주가': self.eval_dict['c101']['주가'],
-            'PER': self.eval_dict['c101']['PER'],
-            'PBR': self.eval_dict['c101']['PBR'],
-            '시가총액': self.eval_dict['c101']['시가총액'],
-            'RED': self.eval_dict['red']['red_price'],
-            '주주수익률': self.eval_dict['mil']['주주수익률'],
-            '이익지표': self.eval_dict['mil']['이익지표'],
-            'ROIC': self.eval_dict['mil']['투자수익률']['ROIC'],
-            'ROE': self.eval_dict['mil']['투자수익률']['ROE'],
-            'PFCF': utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PFCF']),
-            'PCR': utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PCR']),
+            '주가': utils.to_int(self.eval_dict['c101']['주가']),
+            'PER': utils.to_float(self.eval_dict['c101']['PER']),
+            'PBR': utils.to_float(self.eval_dict['c101']['PBR']),
+            '시가총액': utils.to_float(self.eval_dict['c101']['시가총액']),
+            'RED': utils.to_int(self.eval_dict['red']['red_price']),
+            '주주수익률': utils.to_float(self.eval_dict['mil']['주주수익률']),
+            '이익지표': utils.to_float(self.eval_dict['mil']['이익지표']),
+            'ROIC': utils.to_float(self.eval_dict['mil']['투자수익률']['ROIC']),
+            'ROE': utils.to_float(self.eval_dict['mil']['투자수익률']['ROE']),
+            'PFCF': utils.to_float(utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PFCF'])),
+            'PCR': utils.to_float(utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PCR'])),
         }
 
 
